@@ -1,10 +1,5 @@
 package Org::Document;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-06-27'; # DATE
-our $DIST = 'Org-Parser'; # DIST
-our $VERSION = '0.555'; # VERSION
-
 use 5.010001;
 use locale;
 use Log::ger;
@@ -16,6 +11,11 @@ extends 'Org::Element';
 use List::MoreUtils qw(firstidx);
 use Time::HiRes qw(gettimeofday tv_interval);
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-02-08'; # DATE
+our $DIST = 'Org-Parser'; # DIST
+our $VERSION = '0.556'; # VERSION
+
 has tags                    => (is => 'rw');
 has todo_states             => (is => 'rw');
 has done_states             => (is => 'rw');
@@ -787,9 +787,9 @@ sub cmp_priorities {
 
     my $pp = $self->priorities;
     my $pos1 = firstidx {$_ eq $p1} @$pp;
-    return undef unless $pos1 >= 0;
+    return undef unless $pos1 >= 0; ## no critic: Subroutines::ProhibitExplicitReturnUndef
     my $pos2 = firstidx {$_ eq $p2} @$pp;
-    return undef unless $pos2 >= 0;
+    return undef unless $pos2 >= 0; ## no critic: Subroutines::ProhibitExplicitReturnUndef
     $pos1 <=> $pos2;
 }
 
@@ -808,7 +808,7 @@ Org::Document - Represent an Org document
 
 =head1 VERSION
 
-This document describes version 0.555 of Org::Document (from Perl distribution Org-Parser), released on 2021-06-27.
+This document describes version 0.556 of Org::Document (from Perl distribution Org-Parser), released on 2022-02-08.
 
 =head1 SYNOPSIS
 
@@ -918,6 +918,34 @@ Please visit the project's homepage at L<https://metacpan.org/release/Org-Parser
 
 Source repository is at L<https://github.com/perlancar/perl-Org-Parser>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2022, 2021, 2020, 2019, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Org-Parser>
@@ -926,15 +954,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2021, 2020, 2019, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
