@@ -1,8 +1,5 @@
 package Org::Element::TimeRange;
 
-our $DATE = '2021-06-27'; # DATE
-our $VERSION = '0.555'; # VERSION
-
 use 5.010;
 use locale;
 use Moo;
@@ -10,6 +7,11 @@ extends 'Org::Element';
 with 'Org::Element::Role';
 with 'Org::Element::InlineRole';
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-02-08'; # DATE
+our $DIST = 'Org-Parser'; # DIST
+our $VERSION = '0.556'; # VERSION
+
 has ts1 => (is => 'rw');
 has ts2 => (is => 'rw');
 
@@ -42,7 +44,7 @@ Org::Element::TimeRange - Represent Org time range (TS1--TS2)
 
 =head1 VERSION
 
-This document describes version 0.555 of Org::Element::TimeRange (from Perl distribution Org-Parser), released on 2021-06-27.
+This document describes version 0.556 of Org::Element::TimeRange (from Perl distribution Org-Parser), released on 2022-02-08.
 
 =head1 DESCRIPTION
 
@@ -76,6 +78,34 @@ Please visit the project's homepage at L<https://metacpan.org/release/Org-Parser
 
 Source repository is at L<https://github.com/perlancar/perl-Org-Parser>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2022, 2021, 2020, 2019, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Org-Parser>
@@ -84,15 +114,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2021, 2020, 2019, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
